@@ -2,6 +2,9 @@ from .date_time import is_numeric, string_to_datetime, datetime_to_string, forma
 from .csv import CSVHandler, FpCSVEncodingError
 from .columns import get_column_name, get_unique_column_name
 from .parquet_handler import ParquetHandler
+from .attribution_tools import Shapley
+from .ipf import Ipf
+from .athena_partition import athena_partition
 
 __all__ = ['is_numeric',
            'string_to_datetime',
@@ -11,5 +14,7 @@ __all__ = ['is_numeric',
            'FpCSVEncodingError',
            'get_column_name',
            'get_unique_column_name',
-           'ParquetHandler'
-          ]
+           'ParquetHandler',
+           'Shapley',
+           'athena_partition'
+           ]
