@@ -230,6 +230,12 @@ class CSVOtherTests(unittest.TestCase):
         df2 = csv.load_df("zip/test2.csv.zip")
         pd.testing.assert_frame_equal(df1, df2)
 
+    def test_forcing_dtype(self):
+        csv = CSVHandler(base_path=self.orig_base_path)
+        df1 = csv.load_df("number/test_int_is_unique_clean.csv", force_dtype=str)
+        self.assertEqual(str(df1['TotalEpisodes'].dtype), 'object')
+
+
     def test_no_header(self):
         csv = CSVHandler(base_path=self.orig_base_path)
         df = csv.load_df("lookup/test_cities_reference1252.csv",
